@@ -17,13 +17,13 @@ log.addHandler(logging.NullHandler())
 
 
 class RootUpdateProgress(UpdateProgress):
-
     """Utility class which adds more opcodes to the UpdateProgress"""
     REMOVE, PATHCHANGE, BRANCHCHANGE, URLCHANGE = [
         1 << x for x in range(UpdateProgress._num_op_codes, UpdateProgress._num_op_codes + 4)]
     _num_op_codes = UpdateProgress._num_op_codes + 4
 
-    __slots__ = tuple()
+    __slots__ = ()
+
 
 BEGIN = RootUpdateProgress.BEGIN
 END = RootUpdateProgress.END
@@ -38,7 +38,7 @@ class RootModule(Submodule):
     """A (virtual) Root of all submodules in the given repository. It can be used
     to more easily traverse all submodules of the master repository"""
 
-    __slots__ = tuple()
+    __slots__ = ()
 
     k_root_name = '__ROOT__'
 
